#
# spec file for package libtheora
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libtheora
Summary:        Theora video compression codec
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Other
Version:        1.2.0
Release:        1.1
URL:            http://www.theora.org/
Source0:        https://gitlab.xiph.org/xiph/theora/-/archive/v%{version}/theora-v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(vorbis)

%description
Theora is a free and open video compression format from the Xiph.org Foundation. Like all our
multimedia technology it can be used to distribute film and video online and on disc without
the licensing and royalty fees or vendor lock-in associated with other formats.

%package -n libtheora1
Summary:        Theora video compression codec
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libtheora1
Theora is a free and open video compression format from the Xiph.org Foundation. Like all our
multimedia technology it can be used to distribute film and video online and on disc without
the licensing and royalty fees or vendor lock-in associated with other formats.

Theora scales from postage stamp to HD resolution, and is considered particularly competitive
at low bitrates. It is in the same class as MPEG-4/DiVX, and like the Vorbis audio codec it
has lots of room for improvement as encoder technology develops.

Theora is in full public release as of November 3, 2008. The bitstream format for Theora I
was frozen Thursday, 2004 July 1. All bitstreams encoded since that date will remain compatible
with future releases.

The package contains the library that can decode and encode Theora streams. Theora is also
able to playback VP3 streams.

Authors:
--------
    the Xiph.Org Foundation http://www.xiph.org/

%package -n libtheoradec2
Summary:        Theora video decompression library
Group:          System/Libraries

%description -n libtheoradec2
Theora is a free and open video compression format from the Xiph.org Foundation. Like all our
multimedia technology it can be used to distribute film and video online and on disc without
the licensing and royalty fees or vendor lock-in associated with other formats.

This subpackage contains the decoder library.

%package -n libtheoraenc2
Summary:        Theora video compression library
Group:          System/Libraries

%description -n libtheoraenc2
Theora is a free and open video compression format from the Xiph.org Foundation. Like all our
multimedia technology it can be used to distribute film and video online and on disc without
the licensing and royalty fees or vendor lock-in associated with other formats.

This subpackage contains the encoder library.

%package devel
Summary:        Theora video compression codec
Group:          Development/Libraries/C and C++
Requires:       libogg-devel
Requires:       libtheora1 = %{version}
Requires:       libtheoradec2 = %{version}
Requires:       libtheoraenc2 = %{version}

%description devel
Theora is a free and open video compression format from the Xiph.org Foundation. Like all our
multimedia technology it can be used to distribute film and video online and on disc without
the licensing and royalty fees or vendor lock-in associated with other formats.

Theora scales from postage stamp to HD resolution, and is considered particularly competitive
at low bitrates. It is in the same class as MPEG-4/DiVX, and like the Vorbis audio codec it
has lots of room for improvement as encoder technology develops.

Theora is in full public release as of November 3, 2008. The bitstream format for Theora I
was frozen Thursday, 2004 July 1. All bitstreams encoded since that date will remain compatible
with future releases.

The package contains the library that can decode and encode Theora streams. Theora is also
able to playback VP3 streams.

Authors:
--------
    the Xiph.Org Foundation http://www.xiph.org/

%prep
%autosetup -n theora-v%{version}

%build
./autogen.sh
%configure --disable-examples \
    --disable-static \
    --with-pic
%make_build docdir=%{_docdir}/%{name}

%install
%make_install docdir=%{_docdir}/%{name}

# remove la files
find %{buildroot} -type f -name "*.la" -exec rm {} \;
# remove empty file
find %{buildroot} -type f -name "doxygen-build.stamp" -exec rm {} \;

%check
%make_build check

%ldconfig_scriptlets -n libtheora1
%ldconfig_scriptlets -n libtheoradec2
%ldconfig_scriptlets -n libtheoraenc2

%files -n libtheora1
%{_libdir}/libtheora.so.1*

%files -n libtheoradec2
%{_libdir}/libtheoradec.so.2*

%files -n libtheoraenc2
%{_libdir}/libtheoraenc.so.2*

%files devel
%license COPYING LICENSE
%doc AUTHORS CHANGES README.md
%{_docdir}/%{name}
%{_includedir}/theora
%{_libdir}/libtheora.so
%{_libdir}/libtheoradec.so
%{_libdir}/libtheoraenc.so
%{_libdir}/pkgconfig/theora.pc
%{_libdir}/pkgconfig/theoradec.pc
%{_libdir}/pkgconfig/theoraenc.pc

%changelog
* Mon Mar 31 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Fix devel package Requires, so name of shared libs was changed in
  previous version update.
* Sat Mar 29 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.2.0
  * New 'ptalarbvorm' encoder with better rate/distortion optimization
  * New th_encode_ctl option for copying configuration from an existing
    setup header, useful for splicing streams.
  * Returns TH_DUPFRAME in more cases.
  * Add ARM optimizations
  * Add TI C64x+ DSP optimizations
  * Other performance improvements
  * Rename speedlevel 2 to 3 and provide a new speedlevel 2
  * Various minor bug fixes
  * Bumped minor SONAME versions as <codec.h> methods changed constness
    of arguments.
  * Updated libogg dependency to version 1.3.4 for ogg_uint64_t.
  * Updated doxygen setup.
  * Updated autotools setup and support scripts
  * Improved ARM support.
  * Converted SCons setup to work with Python 3.
  * Introduced new configure options --enable-mem-constraint and
  - -enable-gcc-sanitizers.
  * Fixed all known compiler warnings and errors from gcc and clang.
  * Improved examples for stability and correctness.
  * Various speed, bug fixes and code quality improvements.
  - Fixed build problem with Visual Studio
  - Avoids undefined bit shift of signed numbers
  - Avoids example encoder crash on bogus audio input
  - Fixed musl linking issue with asm enabled
  - Fixed some broken clamping in rate control
  - Added NULL check _tc and _setup even for data packets
  - Fixed mismatched oc_mb_fill_cmapping11 signature
  - Updated the documentation for theora_encode_comment()
  - Adjusted build to only link libcompat with dump_video
  - Corrected an operator precedence error in the visualization
    code
  - Fixed two spelling errors in the comments
  - Avoid negative bit shift operation in huffdec.c (CVE-2024-56431)
  * Improved library documentation and specification text.
  * Adjusted library dependencies so libtheoraenc do not depend on
    libtheoradec.
  * Handle fallout from CVE-2017-14633 in libvorbis, check return value
    in encoder_example and transcoder_example.
  * Bumped minor SONAME versions as oc_comment_unpack() implementation
    changed.
  * Added example wrapper script encoder_example_ffmpeg
  * Improve comment handling on platforms where malloc(0) return NULL
  * Added pragma in example code to quiet clang op precedenca warnings.
  * Adjusted encoder_example help text.
  * Adjusted README, CHANGES, pkg-config and spec files to better reflect
    current release
  * Corrected english typos in source and build system.
  * Switched http links to https in doc and comments where relevant.
    Did not touch RFC drafts.
- do not obsolete itself
- remove workaround for ppc64 as that arch does not exist anymore
- use macros (autosetup, make, ldconfig_scriptlets)
- be more verbose in the %%files section (list every file)
* Mon Jun 21 2021 Matej Cepl <mcepl@suse.com>
- Remove completely unnecessary python BR
* Sat Aug 30 2014 jengelh@inai.de
- Split libtheoradec/enc from libtheora0 as they have different
  SO numbers
- Trim huge description; improve on RPM group classificaiton
* Thu May 23 2013 idonmez@suse.com
- Update descriptions, thanks to Perry Werneck
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Aug 29 2011 crrodriguez@opensuse.org
- remove examples that fail to build, also SDL and png
  are only needed for those, so remove from buildrequires.
* Wed Jul 27 2011 crrodriguez@opensuse.org
- remove fno-strict-aliasing from CFLAGS as it is no longer
  needed and will slow down things.
* Mon May 23 2011 crrodriguez@opensuse.org
- Disable doxygen documentation to avoid build dates in
  - devel packages.
- add missing BuildRequires libpng-devel
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Oct  7 2009 adrian@suse.de
- update to version 1.1.1
  * minor bugfixes
* Sat Sep 26 2009 adrian@suse.de
- update to version 1.1.0
  * minor fixes since beta 3
* Thu Aug 27 2009 adrian@suse.de
- update to version 1.1 beta 3
  * Much better encoder
    (faster and more details at same compressions level)
  * Playback received speed improvements, but bitstream format is
    untouched
- no package split yet for dec/enc/legacy libs due to 11.2 freeze
* Fri Jul 17 2009 adrian@suse.de
- update to version 1.0 final
  * new additional encoder and decoder libs with new api.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 13 2007 crrodriguez@suse.de
- fix package version numbers 1.0beta1 --> 1.0.beta2
- libtheora 1.0.beta2
  - Fix a crash bug on char-is-unsigned architectures (PowerPC)
  - Fix a buffer sizing issue that caused rare encoder crashes
  - Fix a buffer alignment issue
  - Improved format documentation.
- removed unneeded patch, use --with-pic configure option instead.
* Thu Nov  8 2007 adrian@suse.de
- fix compiling with gcc 4.3 on ia32
* Wed Sep 26 2007 adrian@suse.de
- update to 1.0beta1
  From official changelog:
  * Granulepos scheme modified to match other codecs. This bumps
  the bitstream revision to 3.2.1. Bitstreams marked 3.2.0 are
  handled correctly by this decoder. Older decoders will show
  a one frame sync error in the less noticable direction.
  * Switch to new spec compliant decoder from theora-exp branch.
  Written by Dr. Timothy Terriberry.
  * Add support to the encoder for using quantization settings
  provided by the application.
  * more assembly optimizations
* Wed Aug 15 2007 coolo@suse.de
- fixing upgrade (#293401)
* Sat Aug 11 2007 crrodriguez@suse.de
- fix build in x86_64
- use library packaging policy
- run make check in the check section
- add missing call to ldconfig
* Wed Mar 28 2007 sbrabec@suse.cz
- Updated to version 1.0alpha7:
  * Enable mmx assembly by default
  * Avoid some relocations that caused problems on SELinux
  * Other build fixes
  * time testing mode (-f) for the dump_video example
  * Merge theora-mmx simd acceleration (x86_32 and x86_64)
  * Major RTP payload specification update
  * Minor format specification updates
  * Fix some spurious calls to free() instead of _ogg_free()
  * Fix invalid array indexing in PixelLineSearch()
  * Improve robustness against invalid input
  * General warning cleanup
  * The offset_y member meaning fix.
- Use incremental versioning scheme.
- Documentation repackaged.
- Use less vague names for binaries.
* Tue Aug  1 2006 dmueller@suse.de
- Reenable test suite run with valgrind.
* Fri Jul 28 2006 aj@suse.de
- Disable test suite run with valgrind.
* Fri Mar 10 2006 bk@suse.de
- libtheora-devel: add libogg-devel to Requires (found by .la check)
* Mon Feb  6 2006 adrian@suse.de
- add -fstack-protector
- enable test suite run with valgrind
* Sun Jan 29 2006 aj@suse.de
- Fix BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 19 2005 adrian@suse.de
- update to version 1.0 alpha 5
- enable test suite
- generate API documentation with doxygen
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Wed Jan  5 2005 adrian@suse.de
- update to version 1.0 alpha 4
* Tue Oct 26 2004 adrian@suse.de
- remove .svn directories
* Mon Oct 18 2004 adrian@suse.de
- update to current cvs to get pc file
* Thu Aug 19 2004 adrian@suse.de
- create -devel package
* Tue Jun 29 2004 adrian@suse.de
- do not install the libtool scripts ...
* Sat Apr 24 2004 adrian@suse.de
- use xorg-x11 packages
* Wed Apr 21 2004 adrian@suse.de
- compile with -fno-strict-aliasing
* Sun Mar 21 2004 adrian@suse.de
- update to alpha 3 release
  on disc format is still not frozen, so this remain an internal package
* Wed Feb  4 2004 adrian@suse.de
- remove binaries from example dir (they get installed anyway)
* Fri Jan 30 2004 adrian@suse.de
- initial package of current snapshot (post alpha2)
- internal package only atm
